16.7. cdist-type__apt_norecommends(7) — cdist 6.9.8 documentation

# 16.7. cdist-type__apt_norecommends(7)

## 16.7.1. NAME

cdist-type__apt_norecommends - Configure apt to not install recommended packages

## 16.7.2. DESCRIPTION

Configure apt to not install any recommended or suggested packages.

## 16.7.3. REQUIRED PARAMETERS

None.

## 16.7.4. OPTIONAL PARAMETERS

None.

## 16.7.5. EXAMPLES

    __apt_norecommends

## 16.7.6. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc> Dennis Camera <dennis.camera--@--ssrq-sds-fds.ch>

## 16.7.7. COPYING

Copyright (C) 2014 Steven Armstrong, 2020 Dennis Camera. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.